@@ -4,19 +4,8 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
 Here we define replacement classes for the case that we have no
@@ -31,14 +20,8 @@ import subprocess
 import getpass
 import webbrowser
 import codecs
-if os.name != 'nt':
-    import pwd
 import weakref
 from collections import defaultdict
-from argparse import ArgumentParser
-
-
-import sip
 
 # pylint: disable=wrong-import-order
 
@@ -51,143 +34,20 @@ from qt import *
 
 from mi18n import MLocale, KDETranslator, i18n, i18nc
 
-from common import Internal, isAlive
+from common import Internal, isAlive, Debug
 from util import popenReadlines
 from statesaver import StateSaver
 
-__all__ = ['KAboutData', 'KApplication', 'KCmdLineArgs', 'KConfig',
-           'KCmdLineOptions',
+if os.name != 'nt':
+    import pwd
+
+__all__ = ['KApplication', 'KConfig',
            'KMessageBox', 'KConfigSkeleton', 'KDialogButtonBox',
            'KConfigDialog', 'KDialog',
            'KUser', 'KStandardAction',
            'KXmlGuiWindow', 'KGlobal', 'KIcon']
 
 
-class OptionHelper:
-
-    """stub"""
-
-    def __init__(self, options):
-        self.options = options
-
-    def isSet(self, option):
-        """did the user specify this option?"""
-        if any(x[0].startswith('no%s' % option) for x in self.options):
-            return not any(x.startswith('--no%s' % option) for x in sys.argv)
-        else:
-            return any(x.startswith('--%s' % option) for x in sys.argv)
-
-    @staticmethod
-    def getOption(option):
-        """try to mimic KDE logic as far as we need it"""
-        for arg in sys.argv:
-            if arg.startswith('--%s' % option):
-                parts = arg.split('=')
-                if len(parts) > 1:
-                    return parts[1]
-                else:
-                    return True
-            if arg.startswith('--no%s' % option):
-                parts = arg.split('=')
-                if len(parts) > 1:
-                    return parts[1]
-                else:
-                    return False
-        return ''
-
-
-class KCmdLineArgs:
-
-    """stub"""
-    options = None
-    argv = None
-    about = None
-
-    @classmethod
-    def parsedArgs(cls):
-        """stub"""
-        if '--help' in sys.argv:
-            KCmdLineOptions.parser.parse_args()
-            KCmdLineOptions.parser.print_help()
-        definitions = list(x[0].split()[0] for x in cls.options.options)
-        definitions = definitions + list('no' + x for x in definitions)
-        for arg in sys.argv[1:]:
-            if not (
-                    arg.startswith('--') or
-                    any(arg[2:].startswith(x) for x in definitions)):
-                print('unrecognized argument:{} '.format(arg))
-                sys.exit(2)
-        return cls.options
-
-    @classmethod
-    def init(cls, argv, about):
-        """stub"""
-        cls.argv = argv
-        cls.about = about
-
-    @classmethod
-    def addCmdLineOptions(cls, options):
-        """stub"""
-        cls.options = OptionHelper(options)
-
-
-class KCmdLineOptions(list):
-
-    """stub"""
-    parser = ArgumentParser()
-
-    def __init__(self):
-        list.__init__(self)
-
-    def add(self, definition, helptext, default=None):
-        """stub"""
-        self.append((definition, helptext, default))
-        # self.parser is currently only used for generating --help text
-        self.parser.add_argument(
-            '--' + definition,
-            dest=definition,
-            help=helptext,
-            action='store_true')
-
-
-class KAboutData:
-
-    """stub"""
-    License_GPL = 1
-
-    def __init__(self, appname, catalog, programName, version, description,
-                 kajLicense, kajCopyright, aboutText, homePage):
-        # pylint: disable=too-many-arguments
-        KGlobal.aboutData = self
-        self.appname = appname
-        self.catalog = catalog
-        self.programName = programName
-        self.version = version
-        self.description = description
-        self.kajLicense = kajLicense
-        self.kajCopyright = kajCopyright
-        self.aboutText = aboutText
-        self.homePage = homePage
-        self._authors = []
-
-    def addAuthor(self, name, description, mailAdress):
-        """authors to be shown on about page"""
-        self._authors.append((name, description, mailAdress))
-
-    def authors(self):
-        """stub"""
-        return self._authors
-
-    @staticmethod
-    def licenseFile():
-        """which may currently only be 1: GPL_V2"""
-        for path in ('COPYING', '../COPYING',
-                     '%s/share/kf5/licenses/GPL_V2' % KGlobal.prefix):
-            path = os.path.abspath(path)
-            if os.path.exists(path):
-                return path
-
-
 class KApplication(QApplication):
 
     """stub"""
@@ -199,7 +59,10 @@ class KApplication(QApplication):
         # Qt uses sys.argv[0] as application name
         # which is used by QStandardPaths - if we start kajongg.py directly,
         # the search path would look like /usr/share/kajongg.py/
+
+        self.translators = []
         self.setApplicationName('kajongg')
+        self.setApplicationVersion(str(Internal.defaultPort))
 
         self.initQtTranslator()
 
@@ -209,10 +72,20 @@ class KApplication(QApplication):
             translator = KDETranslator(self)
             translator.load(qmName)
             self.installTranslator(translator)
+            self.translators.append(translator)
+            if Debug.i18n:
+                Internal.logger.debug('Installed Qt translator from %s', qmName)
+
 
     def initQtTranslator(self):
         """load translators using Qt .qm files"""
-        for language in reversed(list(MLocale.extendRegionLanguages(KGlobal.currentLanguages()))):
+        for _ in self.translators:
+            self.removeTranslator(_)
+        self.translators = []
+        _ = KDETranslator(self)
+        self.translators.append(_)
+        self.installTranslator(_)
+        for language in reversed(list(MLocale.extendRegionLanguages(MLocale.currentLanguages()))):
             self.installTranslatorFile(os.path.join(
                 QLibraryInfo.location(QLibraryInfo.TranslationsPath), 'qtbase_{}.qm'.format(language)))
             self.installTranslatorFile('/usr/share/locale/{}/LC_MESSAGES/kwidgetsaddons5_qt.qm'.format(language))
@@ -240,15 +113,15 @@ class Help:
 
     @staticmethod
     def __getDocUrl(languages):
-        """returns the best match for the online user manual"""
+        """return the best match for the online user manual"""
         from twisted.web import client
 
-        def processResult(dummyResult, fallbacks):
+        def processResult(unusedResult, fallbacks):
             """if status 404, try the next fallback language"""
             return Help.__getDocUrl(fallbacks) if factory.status == '404' else url
         host = 'docs.kde.org'
         path = '?application=kajongg&language={}'.format(languages[0])
-        url = 'http://' + host + path
+        url = 'https://' + host + path
         factory = client.HTTPClientFactory(url.encode('ascii'))
         factory.protocol = client.HTTPPageGetter
         factory.protocol.handleEndHeaders = lambda x: x
@@ -292,7 +165,7 @@ class KMessageBox:
 
     @staticmethod
     def createKMessageBox(
-            dialog, icon, text, dummyStrlist, dummyAsk, dummyCheckboxReturn, options):
+            dialog, icon, text, unusedStrlist, unusedAsk, unusedCheckboxReturn, options):
         """translated as far as needed from kmessagegox.cpp"""
         # pylint: disable=too-many-locals
         mainLayout = QVBoxLayout()
@@ -405,7 +278,7 @@ class KDialog(CaptionMixin, QDialog):
         self.layout().addWidget(self.buttonBox)
 
     def button(self, buttonCode):
-        """returns the matching button"""
+        """return the matching button"""
         return self.buttonBox.button(buttonCode)
 
     @staticmethod
@@ -435,9 +308,7 @@ class KUser:
         """stub"""
         if os.name == 'nt':
             return self.loginName()
-        else:
-            return pwd.getpwnam(self.loginName()).pw_gecos.replace(',', '')
-        return None
+        return pwd.getpwnam(self.loginName()).pw_gecos.replace(',', '')
 
     @staticmethod
     def loginName():
@@ -454,15 +325,13 @@ class KStandardAction:
         mainWindow = Internal.mainWindow
         separator = QAction(Internal.mainWindow)
         separator.setSeparator(True)
-        mainWindow.actionStatusBar = mainWindow.kajonggAction(
-            'options_show_statusbar', None)
+        mainWindow.actionStatusBar = Action(mainWindow, 'options_show_statusbar', None)
         mainWindow.actionStatusBar.setCheckable(True)
         mainWindow.actionStatusBar.setEnabled(True)
         mainWindow.actionStatusBar.toggled.connect(mainWindow.toggleStatusBar)
         mainWindow.actionStatusBar.setText(
             i18nc('@action:inmenu', "Show St&atusbar"))
-        mainWindow.actionToolBar = mainWindow.kajonggAction(
-            'options_show_toolbar', None)
+        mainWindow.actionToolBar = Action(mainWindow, 'options_show_toolbar', None)
         mainWindow.actionToolBar.setCheckable(True)
         mainWindow.actionToolBar.setEnabled(True)
         mainWindow.actionToolBar.toggled.connect(mainWindow.toggleToolBar)
@@ -482,7 +351,7 @@ class KStandardAction:
 
         action = QAction(mainWindow)
         action.triggered.connect(slot)
-        action.setText(i18n('Configure &Kajongg'))
+        action.setText(i18n('Configure &Kajongg...'))
         action.setIcon(KIcon('configure'))
         action.setIconText(i18n('Configure'))
         actionCollection.addAction('options_configure', action)
@@ -580,12 +449,12 @@ class KXmlGuiWindow(CaptionMixin, QMainWindow):
             self.menus[menu] = (mainMenu, menuItems)
             self.menuBar().addMenu(mainMenu)
         self.setCaption('')
-        self.actionHelp = self.kajonggAction("help", "help-contents", Help.start)
+        self.actionHelp = Action(self, "help", "help-contents", Help.start)
         self.actionHelp.setText(i18nc('@action:inmenu', '&Help'))
-        self.actionLanguage = self.kajonggAction(
+        self.actionLanguage = Action(self,
             "language", "preferences-desktop-locale", self.selectLanguage)
         self.actionLanguage.setText(i18n('Switch Application Language'))
-        self.actionAboutKajongg = self.kajonggAction(
+        self.actionAboutKajongg = Action(self,
             'aboutkajongg', 'kajongg', self.aboutKajongg)
         self.actionAboutKajongg.setText(
             i18nc('@action:inmenu', 'About &Kajongg'))
@@ -639,13 +508,9 @@ class KXmlGuiWindow(CaptionMixin, QMainWindow):
         """stub"""
         return self._toolBar
 
-    def kajonggAction(
-            self, name, icon, slot=None, shortcut=None, actionData=None):
-        """this is defined in MainWindow(KXmlGuiWindow)"""
-
     @staticmethod
     def selectLanguage():
-        """show an about dialog"""
+        """switch the language"""
         KSwitchLanguageDialog(Internal.mainWindow).exec_()
 
     @staticmethod
@@ -683,6 +548,7 @@ class KConfigGroup:
             return default
         if self.groupName == 'Locale' and name == 'Language':
             return QLocale().name()
+        return None
 
     def readEntry(self, name, default=None):
         """get an entry from this group."""
@@ -690,24 +556,21 @@ class KConfigGroup:
             items = self.config().items(self.groupName)
         except NoSectionError:
             return self.__default(name, default)
-        items = dict((x for x in items if x[0].startswith(name)))
-        i18nItems = dict(
-            (x for x in items.items() if x[0].startswith(name + '[')))
+        items = {x: y for x, y in items if x.startswith(name)}
+        i18nItems = {x: y for x, y in items.items() if x.startswith(name + '[')}
         if i18nItems:
             languages = Internal.kajonggrc.group('Locale').readEntry('Language').split(':')
-            languages = list(x.split('_')[0] for x in languages)
+            languages = [x.split('_')[0] for x in languages]
             for language in languages:
                 key = '%s[%s]' % (name, language)
                 if key in i18nItems:
                     return i18nItems[key]
         if name in items:
             if self.groupName == 'Locale' and name == 'Language':
-                languages = list(x for x in items[name].split(
-                    ':') if MLocale.isLanguageInstalled(x))
+                languages = [x for x in items[name].split(':') if MLocale.isLanguageInstalled(x)]
                 if languages:
                     return ':'.join(languages)
-                else:
-                    return QLocale().name()
+                return QLocale().name()
             return items[name]
         return self.__default(name, default)
 
@@ -715,35 +578,21 @@ class KConfigGroup:
         """calls readEntry and returns it as an int or raises an Exception."""
         try:
             return int(self.readEntry(name, default))
-        except Exception:
+        except Exception as _:
             raise Exception('cannot parse group {} in {}: {}={}'.format(
                 self.groupName, self.config().path, name,
                 self.readEntry(name, default)
-                ))
+                )) from _
 
 
 class KGlobal:
 
     """stub"""
 
-    @classmethod
-    def currentLanguages(cls):
-        """the currently used languages, primary first"""
-        languages = Internal.kajonggrc.group('Locale').readEntry('Language')
-        if not languages:
-            return list()
-        languages = languages.split(':')
-        if 'en_US' in languages:
-            languages.remove('en_US')
-        return languages
-
     @classmethod
     def initStatic(cls):
         """init class members"""
-        cls.prefix = QLibraryInfo.location(QLibraryInfo.PrefixPath)
         Internal.kajonggrc = KConfig()
-        MLocale.installTranslations(cls.currentLanguages())
-
 
 class KConfig(ConfigParser):
 
@@ -761,9 +610,9 @@ class KConfig(ConfigParser):
             with codecs.open(self.path, 'r', encoding='utf-8') as cfgFile:
                 self.read_file(cfgFile)
 
-    def optionxform(self, value):
+    def optionxform(self, optionstr):
         """KDE needs upper/lowercase distinction"""
-        return value
+        return optionstr
 
     def setValue(self, section, option, value):
         """like set but add missing section"""
@@ -784,8 +633,26 @@ def KIcon(name=None):  # pylint: disable=invalid-name
     """simple wrapper"""
     if os.name == 'nt':
         return QIcon(os.path.join('share', 'icons', name) if name else None)
-    else:
-        return QIcon.fromTheme(name)
+    return QIcon.fromTheme(name)
+
+
+class Action(QAction):
+
+    """helper for creation QAction"""
+
+    def __init__(self, parent, name, icon, slot=None, shortcut=None, actionData=None):
+        super().__init__(parent)
+        if icon:
+            self.setIcon(KIcon(icon))
+        if slot:
+            self.triggered.connect(slot)
+        if parent:
+            parent.actionCollection().addAction(name, self)
+        if shortcut:
+            self.setShortcut(Qt.CTRL + shortcut)
+            self.setShortcutContext(Qt.ApplicationShortcut)
+        if actionData is not None:
+            self.setData(actionData)
 
 
 class KConfigSkeletonItem:
@@ -873,7 +740,7 @@ class ItemInt(KConfigSkeletonItem):
 class KConfigSkeleton(QObject):
 
     """handles preferences settings"""
-    configChanged = pyqtSignal()
+    configChanged = Signal()
 
     def __init__(self):
         QObject.__init__(self)
@@ -933,7 +800,7 @@ class KSwitchLanguageDialog(KDialog):
     """select application language"""
 
     def __init__(self, parent):
-        super(KSwitchLanguageDialog, self).__init__(parent)
+        super().__init__(parent)
         self.languageRows = dict()
         self.languageButtons = list()
         self.setCaption(i18n('Switch Application Language'))
@@ -1005,7 +872,7 @@ class KSwitchLanguageDialog(KDialog):
         """OK"""
         newValue = ':'.join(x.current for x in self.languageButtons)
         Internal.kajonggrc.setValue('Locale', 'Language', newValue)
-        super(KSwitchLanguageDialog, self).accept()
+        super().accept()
 
     def slotAddLanguageButton(self):
         """adding a new button with en_US as it should always be present"""
@@ -1013,10 +880,10 @@ class KSwitchLanguageDialog(KDialog):
 
     def restoreDefaults(self):
         """reset values to default"""
-        keys = list(x for x in self.languageRows.keys() if isinstance(x, KLanguageButton))
-        for _ in keys:
-            self.removeLanguage(_)
-        for removeButton in self.languageRows.keys():
+        for _ in self.languageRows:
+            if isinstance(_, KLanguageButton):
+                self.removeLanguage(_)
+        for removeButton in self.languageRows:
             if isAlive(removeButton):
                 removeButton.deleteLater()
         self.languageRows = dict()
@@ -1040,7 +907,7 @@ class KLanguageButton(QWidget):
     """A language button for KSwitchLanguageDialog"""
 
     def __init__(self, txt, parent=None):
-        super(KLanguageButton, self).__init__(parent)
+        super().__init__(parent)
         self.button = QPushButton(txt)
         self.popup = QMenu()
         self.button.setMenu(self.popup)
@@ -1099,6 +966,7 @@ class KLanguageButton(QWidget):
         for action in self.popup.actions():
             if action.data() == data:
                 return action
+        return None
 
 
 class AboutKajonggDialog(KDialog):
@@ -1107,6 +975,7 @@ class AboutKajonggDialog(KDialog):
     def __init__(self, parent):
         # pylint: disable=too-many-locals, too-many-statements
         from twisted import __version__
+
         KDialog.__init__(self, parent)
         self.setCaption(i18n('About Kajongg'))
         self.setButtons(KDialog.Close)
@@ -1115,7 +984,28 @@ class AboutKajonggDialog(KDialog):
         hLayout1.addWidget(IconLabel('kajongg', self))
         h1vLayout = QVBoxLayout()
         h1vLayout.addWidget(QLabel('Kajongg'))
+        try:
+            from appversion import VERSION
+        except ImportError:
+            VERSION = "Unknown"
+
+        if os.environ['QT_API'].startswith('pyqt'):
+            # pylint: disable=no-name-in-module
+            from PyQt5.sip import SIP_VERSION_STR
+            from PyQt5.QtCore import PYQT_VERSION_STR
+            from PyQt5.QtCore import QT_VERSION_STR
+            qtVersion = 'Qt {} with PyQt5 {} sip {}'.format(QT_VERSION_STR, PYQT_VERSION_STR, SIP_VERSION_STR)
+        else:
+            import PySide2 as PySide
+            qtVersion = 'Qt {} with Pyside2 {} compiled with Qt {}'.format(
+                PySide.QtCore.qVersion(), PySide.__version__, PySide.QtCore.__version__)
+
+        h1vLayout.addWidget(QLabel(i18n('Version: %1', VERSION)))
         h1vLayout.addWidget(QLabel(i18n('Protocol version %1', Internal.defaultPort)))
+        authors = ((
+            "Wolfgang Rohdewald",
+            i18n("Original author"),
+            "wolfgang@rohdewald.de"), )
         underVersions = []
         try:
             versions = popenReadlines('kf5-config -v')
@@ -1123,9 +1013,7 @@ class AboutKajonggDialog(KDialog):
             underVersions.append('KDE Frameworks %s' % versionsDict['KDE Frameworks'])
         except OSError:
             underVersions.append(i18n('KDE Frameworks (not installed or not usable)'))
-        underVersions.append('Qt %s' % QT_VERSION_STR)
-        underVersions.append('PyQt %s' % PYQT_VERSION_STR)
-        underVersions.append('sip %s' % sip.SIP_VERSION_STR)
+        underVersions.append(qtVersion)
         underVersions.append('Twisted %s' % __version__)
         underVersions.append(
             'Python {}.{}.{} {}'.format(*sys.version_info[:5]))
@@ -1135,7 +1023,7 @@ class AboutKajonggDialog(KDialog):
                       'Using versions %1',
                       ', '.join(
                           underVersions))))
-        h1vLayout.addWidget(QLabel(i18n('Not using Python KDE bindings')))
+        h1vLayout.addWidget(QLabel(i18n('Not using broken Python KDE bindings')))
         hLayout1.addLayout(h1vLayout)
         spacerItem = QSpacerItem(
             20,
@@ -1146,21 +1034,24 @@ class AboutKajonggDialog(KDialog):
         vLayout.addLayout(hLayout1)
         tabWidget = QTabWidget()
 
-        data = KGlobal.aboutData
-
         aboutWidget = QWidget()
         aboutLayout = QVBoxLayout()
         aboutLabel = QLabel()
         aboutLabel.setWordWrap(True)
         aboutLabel.setOpenExternalLinks(True)
         aboutLabel.setText(
-            '<br /><br />'.join([data.description, data.aboutText,
-                                 data.kajCopyright,
-                                 '<a href="{link}">{link}</a>'.format(link=data.homePage)]))
+            '<br /><br />'.join([
+                i18n("Mah Jongg - the ancient Chinese board game for 4 players"),
+                i18n("This is the classical Mah Jongg for four players. "
+                     "If you are looking for Mah Jongg solitaire please "
+                     "use the application kmahjongg."),
+                "(C) 2008-2017 Wolfgang Rohdewald",
+                '<a href="{link}">{link}</a>'.format(
+                    link='https://apps.kde.org/kajongg')]))
         licenseLabel = QLabel()
         licenseLabel.setText(
             '<a href="file://{link}">GNU General Public License Version 2</a>'.format(
-                link=data.licenseFile()))
+                link=self.licenseFile()))
         licenseLabel.linkActivated.connect(self.showLicense)
         aboutLayout.addWidget(aboutLabel)
         aboutLayout.addWidget(licenseLabel)
@@ -1170,7 +1061,7 @@ class AboutKajonggDialog(KDialog):
         authorWidget = QWidget()
         authorLayout = QVBoxLayout()
         bugsLabel = QLabel(
-            i18n('Please use <a href="http://bugs.kde.org">http://bugs.kde.org</a> to report bugs.'))
+            i18n('Please use <a href="https://bugs.kde.org">https://bugs.kde.org</a> to report bugs.'))
         bugsLabel.setContentsMargins(0, 2, 0, 4)
         bugsLabel.setOpenExternalLinks(True)
         authorLayout.addWidget(bugsLabel)
@@ -1178,7 +1069,7 @@ class AboutKajonggDialog(KDialog):
         titleLabel = QLabel(i18n('Authors:'))
         authorLayout.addWidget(titleLabel)
 
-        for name, description, mail in data.authors():
+        for name, description, mail in authors:
             label = QLabel('{name} <a href="mailto:{mail}">{mail}</a>: {description}'.format(
                 name=name, mail=mail, description=description))
             label.setOpenExternalLinks(True)
@@ -1198,22 +1089,33 @@ class AboutKajonggDialog(KDialog):
         self.buttonBox.setFocus()
 
     @staticmethod
-    def showLicense():
+    def licenseFile():
+        """which may currently only be 1: GPL_V2"""
+        prefix = QLibraryInfo.location(QLibraryInfo.PrefixPath)
+        for path in ('COPYING', '../COPYING',
+                     '%s/share/kf5/licenses/GPL_V2' % prefix):
+            path = os.path.abspath(path)
+            if os.path.exists(path):
+                return path
+        return None
+
+    @classmethod
+    def showLicense(cls):
         """as the name says"""
-        LicenseDialog(Internal.mainWindow).exec_()
+        LicenseDialog(Internal.mainWindow, cls.licenseFile()).exec_()
 
 
 class LicenseDialog(KDialog):
 
     """see kaboutapplicationdialog.cpp"""
 
-    def __init__(self, parent):
+    def __init__(self, parent, licenseFile):
         KDialog.__init__(self, parent)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.setCaption(i18n("License Agreement"))
         self.setButtons(KDialog.Close)
         self.buttonBox.setFocus()
-        licenseText = open(KGlobal.aboutData.licenseFile(), 'r').read()
+        licenseText = open(licenseFile, 'r').read()
         self.licenseBrowser = QTextBrowser()
         self.licenseBrowser.setLineWrapMode(QTextEdit.NoWrap)
         self.licenseBrowser.setText(licenseText)
@@ -1286,8 +1188,9 @@ class KConfigDialog(KDialog):
             cls.dialog.updateButtons()
             cls.dialog.show()
             return cls.dialog
+        return None
 
-    def showEvent(self, dummyEvent):
+    def showEvent(self, unusedEvent):
         """if the settings dialog shows, remember current values
         and show them in the widgets"""
         self.orgPref = self.preferences.as_dict()
@@ -1321,13 +1224,13 @@ class KConfigDialog(KDialog):
         self.iconList.addItem(item)
         self.tabSpace.addWidget(configTab)
         self.iconList.setIconSize(QSize(80, 80))
-        icons = list(self.iconList.item(x) for x in range(len(self.iconList)))
+        icons = [self.iconList.item(x) for x in range(self.iconList.count())]
         neededIconWidth = max(self.iconList.visualItemRect(x).width()
                               for x in icons)
         margins = self.iconList.contentsMargins()
         neededIconWidth += margins.left() + margins.right()
         self.iconList.setFixedWidth(neededIconWidth)
-        self.iconList.setMinimumHeight(120 * len(self.iconList))
+        self.iconList.setMinimumHeight(120 * self.iconList.count())
         for child in self.allChildren(self):
             self.configWidgets[
                 child.objectName().replace('kcfg_', '')] = child
@@ -1410,13 +1313,12 @@ class ToolBarItem(QListWidgetItem):
     def __init__(self, action, parent):
         self.action = action
         self.parent = parent
-        QListWidgetItem.__init__(self, self.icon, self.text, parent)
+        QListWidgetItem.__init__(self, self.__icon(), self.__text(), parent)
         # drop between items, not onto items
         self.setFlags(
             (self.flags() | Qt.ItemIsDragEnabled) & ~Qt.ItemIsDropEnabled)
 
-    @property
-    def icon(self):
+    def __icon(self):
         """the action icon, default is an empty icon"""
         result = self.action.icon()
         if result.isNull():
@@ -1429,8 +1331,7 @@ class ToolBarItem(QListWidgetItem):
             result = self.emptyIcon
         return result
 
-    @property
-    def text(self):
+    def __text(self):
         """the action text"""
         return self.action.text().replace('&', '')
 
@@ -1615,9 +1516,8 @@ class KEditToolBar(KDialog):
             ).actions(
             ).items(
             )}
-        activeNames = list(names[x] for x in activeActions)
         Internal.Preferences.toolBarActions = ','.join(
-            activeNames)  # pylint: disable=attribute-defined-outside-init
+            names[x] for x in activeActions)  # pylint: disable=attribute-defined-outside-init
         Internal.mainWindow.refreshToolBar()
 
 KGlobal.initStatic()
